summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsobjecteventproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsobjecteventproxy.h')
-rw-r--r--kjsembed/jsobjecteventproxy.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kjsembed/jsobjecteventproxy.h b/kjsembed/jsobjecteventproxy.h
index 2ef662ae..e05c2b1f 100644
--- a/kjsembed/jsobjecteventproxy.h
+++ b/kjsembed/jsobjecteventproxy.h
@@ -32,12 +32,12 @@ namespace KJSEmbed {
class JSObjectProxy;
/**
* Filters events for a TQObject and forwards them to a JS handler.
*
* @version $Id$
* @author Richard Moore, rich@kde.org
*/
-class KJSEMBED_EXPORT JSObjectEventProxy : public QObject
+class KJSEMBED_EXPORT JSObjectEventProxy : public TQObject
{
Q_OBJECT
@@ -46,26 +46,26 @@ public:
virtual ~JSObjectEventProxy();
/** Returns true iff we forward the event type to JS. */
- bool isFiltered( TQEvent::Type t ) const;
+ bool isFiltered( TTQEvent::Type t ) const;
/** Adds an event type to those we forward to JS. */
- void addFilter( TQEvent::Type t );
+ void addFilter( TTQEvent::Type t );
/**
* Removes an event type from those we forward to JS. If there are no
* event types left to forward then we self-destruct.
*/
- void removeFilter( TQEvent::Type t );
+ void removeFilter( TTQEvent::Type t );
/** Reimplemented to forward events to JS. */
- bool eventFilter ( TQObject *watched, TQEvent *e );
+ bool eventFilter ( TTQObject *watched, TTQEvent *e );
protected:
- KJS::Value callHandler( TQEvent *e );
+ KJS::Value callHandler( TTQEvent *e );
private:
JSObjectProxy *proxy;
- TQBitArray eventMask;
+ TTQBitArray eventMask;
uint refcount;
class JSObjectEventProxyPrivate *d;
};
@@ -32,12 +32,12 @@ namespace KJSEmbed {
class JSObjectProxy;
/**
- * Filters events for a TQObject and forwards them to a JS handler.
+ * Filters events for a TTQObject and forwards them to a JS handler.
*
* @version $Id$